/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 *  Copyright © 2019-2020 Jan-Michael Brummer <jan.brummer@tabos.org>
 *
 *  This file is part of Epiphany.
 *
 *  Epiphany is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Epiphany is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
 */


#pragma once

#include "ephy-web-extension.h"

#include <webkit2/webkit2.h>

G_BEGIN_DECLS

void ephy_web_extension_api_tabs_handler (EphyWebExtensionSender *sender,
                                          const char             *method_name,
                                          JsonArray              *args,
                                          GTask                  *task);

JsonNode *ephy_web_extension_api_tabs_create_tab_object (EphyWebExtension *self,
                                                         EphyWebView      *web_view);

void      ephy_web_extension_api_tabs_add_tab_to_json   (EphyWebExtension *self,
                                                         JsonBuilder      *builder,
                                                         EphyWindow       *window,
                                                         EphyWebView      *web_view);

gboolean  ephy_web_extension_api_tabs_url_is_unprivileged
                                                        (const char       *url);

G_END_DECLS
